//
//  MainWindowController.m
//  ShapedButtonTest
//
//  Created by Andreas on Mon Jul 28 2003.
//  Copyright (c) 2003 Andreas Mayer. All rights reserved.
//
//  2003-08-07 AM	added methods to switch between 'momentary push'
//		and 'on/off' button types


#import "MainWindowController.h"
#import "AMShapedButton.h"

// to avoid warnings when using private methods:
@interface AMShapedButton (MainWindowController)
- (void)controlTintChanged:(NSNotification *)aNotification;
@end

@implementation MainWindowController

// produce some output ...
- (IBAction)up:(id)sender
{
	[textView insertText:@"up\n"];
}

- (IBAction)down:(id)sender
{
	[textView insertText:@"down\n"];
}

- (IBAction)left:(id)sender
{
	[textView insertText:@"left\n"];
}

- (IBAction)right:(id)sender
{
	[textView insertText:@"right\n"];
}

- (IBAction)center:(id)sender
{
	[textView insertText:@"center\n"];
}


// toggle enabled state of shaped buttons
- (IBAction)toggleUp:(id)sender
{
	[upButton setEnabled:([sender state] == NSOnState)];
}

- (IBAction)toggleDown:(id)sender
{
	[downButton setEnabled:([sender state] == NSOnState)];
}

- (IBAction)toggleLeft:(id)sender
{
	[leftButton setEnabled:([sender state] == NSOnState)];
}

- (IBAction)toggleRight:(id)sender
{
	[rightButton setEnabled:([sender state] == NSOnState)];
}

- (IBAction)toggleCenter:(id)sender
{
	[centerButton setEnabled:([sender state] == NSOnState)];
}

// toggle button type of shaped buttons
- (IBAction)toggleTypeUp:(id)sender
{
	if ([sender state] == NSOnState) {
		[upButton setButtonType:NSOnOffButton];
	} else {
		[upButton setButtonType:NSMomentaryPushInButton];
	}
	[upButton setState:NSOffState];
}

- (IBAction)toggleTypeDown:(id)sender
{
	if ([sender state] == NSOnState) {
		[downButton setButtonType:NSOnOffButton];
	} else {
		[downButton setButtonType:NSMomentaryPushInButton];
	}
	[downButton setState:NSOffState];
}

- (IBAction)toggleTypeLeft:(id)sender
{
	if ([sender state] == NSOnState) {
		[leftButton setButtonType:NSOnOffButton];
	} else {
		[leftButton setButtonType:NSMomentaryPushInButton];
	}
	[leftButton setState:NSOffState];
}

- (IBAction)toggleTypeRight:(id)sender
{
	if ([sender state] == NSOnState) {
		[rightButton setButtonType:NSOnOffButton];
	} else {
		[rightButton setButtonType:NSMomentaryPushInButton];
	}
	[rightButton setState:NSOffState];
}

- (IBAction)toggleTypeCenter:(id)sender
{
	if ([sender state] == NSOnState) {
		[centerButton setButtonType:NSOnOffButton];
	} else {
		[centerButton setButtonType:NSMomentaryPushInButton];
	}
	[centerButton setState:NSOffState];
}

// select either predefined images or auto tinting for
// pressed state (NSOnState)
- (IBAction)toggleImages:(id)sender
{
	// please note that the methods used here are private -
	// you usually won't want to use auto tinting if you have
	// appropriate images anyway  ;)
	if ([[sender selectedCell] tag] == 0) {
		// set alternate images
		[(AMShapedButton *)upButton setImageBaseName:@"Up On "];
		[(AMShapedButton *)downButton setImageBaseName:@"Down On "];
		[(AMShapedButton *)leftButton setImageBaseName:@"Left On "];
		[(AMShapedButton *)rightButton setImageBaseName:@"Right On "];
		[(AMShapedButton *)centerButton setImageBaseName:@"Center On "];
	} else {
		// remove alternate images
		[(AMShapedButton *)upButton setImageBaseName:@"Up"];
		[(AMShapedButton *)downButton setImageBaseName:@"Down"];
		[(AMShapedButton *)leftButton setImageBaseName:@"Left"];
		[(AMShapedButton *)rightButton setImageBaseName:@"Right"];
		[(AMShapedButton *)centerButton setImageBaseName:@"Center"];
	}
	// update tint
	[(AMShapedButton *)upButton controlTintChanged:nil];
	[(AMShapedButton *)downButton controlTintChanged:nil];
	[(AMShapedButton *)leftButton controlTintChanged:nil];
	[(AMShapedButton *)rightButton controlTintChanged:nil];
	[(AMShapedButton *)centerButton controlTintChanged:nil];
}


@end
